/**
 * Copyright (C) 2022 EEMBC
 * Copyright (C) 2022 Arm Limited
 *
 * All EEMBC Benchmark Software are products of EEMBC and are provided under the
 * terms of the EEMBC Benchmark License Agreements. The EEMBC Benchmark Software
 * are proprietary intellectual properties of EEMBC and its Members and is
 * protected under all applicable laws, including all applicable copyright laws.
 *
 * If you received this EEMBC Benchmark Software without having a currently
 * effective EEMBC Benchmark License Agreement, you must discontinue use.
 */
#include <stdint.h>

//#define PLATFORM_ARCH_32BIT
#define PLATFORM_ARCH_64BIT

// assuming "int" is also the same size as "*int"
#ifdef PLATFORM_ARCH_32BIT
#define PTR_INT uint32_t
#endif
#ifdef PLATFORM_ARCH_64BIT
#define PTR_INT uint64_t
#endif

typedef float               ee_f32_t;
#define PADDED_FRAME_LEN 1024
#define FFT_LEN          PADDED_FRAME_LEN

typedef struct mfcc_instance_t
{
    ee_f32_t      mfcc_input_frame[FFT_LEN];
    ee_f32_t      mfcc_out[10];
    ee_f32_t      tmp[FFT_LEN + 2];
} mfcc_instance_t;

typedef struct kws_instance_t
{
    mfcc_instance_t mfcc_inst;
    int16_t        *p_audio_fifo; // [TOTAL_CHUNKS * SAMPLES_PER_CHUNK];
    int8_t         *p_mfcc_fifo;  // [NUM_MFCC_FRAMES * FEATURES_PER_FRAME];
    int32_t         chunk_idx;
} kws_instance_t;

typedef enum
{
    EE_STATUS_OK = 0,
    EE_STATUS_ERROR
} ee_status_t;

#include <stdio.h>

int32_t
ee_kws_f32(int32_t command, void **pp_inst, void *p_data, void *p_params)
{
    ee_status_t status = EE_STATUS_OK;

            PTR_INT        *p_ptr            = NULL;
            int16_t        *p_inbuf          = NULL;
            int8_t         *p_predictions    = NULL;
            uint32_t        inbuf_size       = 0;
            uint32_t        audio_fifo_size  = 0;
            uint32_t        mfcc_fifo_size   = 0;
            uint32_t        predictions_size = 0;
            int            *new_inference    = (int *)p_params;
            kws_instance_t *p_inst           = *pp_inst;

            p_ptr                = (PTR_INT *)p_data;
            p_inbuf              = (int16_t *)(*p_ptr++);
            inbuf_size           = (uint32_t)(*p_ptr++);
            p_inst->p_audio_fifo = (int16_t *)(*p_ptr++);
            audio_fifo_size      = (uint32_t)(*p_ptr++);
            p_inst->p_mfcc_fifo  = (int8_t *)(*p_ptr++);
            mfcc_fifo_size       = (uint32_t)(*p_ptr++);
            p_predictions        = (int8_t *)(*p_ptr++);
            predictions_size     = (uint32_t)(*p_ptr++);
printf("error\n");

    return status == EE_STATUS_OK ? 0 : 1;
}
